"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const deps_1 = require("./deps");
function validate(parse) {
    function validateArgs() {
        const maxArgs = parse.input.args.length;
        if (parse.input.strict && parse.output.argv.length > maxArgs) {
            const extras = parse.output.argv.slice(maxArgs);
            throw new deps_1.deps.errors.UnexpectedArgsError({ parse, args: extras });
        }
        const requiredArgs = parse.input.args.filter(a => a.required);
        const missingRequiredArgs = requiredArgs.slice(parse.output.argv.length);
        if (missingRequiredArgs.length) {
            throw new deps_1.deps.errors.RequiredArgsError({ parse, args: missingRequiredArgs });
        }
    }
    function validateFlags() {
        const flags = Object.values(parse.input.flags).filter(f => f.required && !parse.output.flags[f.name]);
        if (flags.length)
            throw new deps_1.deps.errors.RequiredFlagError({ parse, flags });
    }
    validateArgs();
    validateFlags();
}
exports.validate = validate;
